@@ -78,7 +78,8 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
             self.udp_ip = connections[1].strip("//")
             self.udp_port = int(connections[2]) if len(connections) > 2 else 80
         else:
-            logger.debug("socket_path参数不合法。")
+            functions.log("socket_path参数不合法")
+            # logger.debug("socket_path参数不合法。")
             return False
 
     def report(self, generator):
@@ -88,11 +89,16 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         :return:
         """
         try:
+            functions.log("udp socket start")
             udp_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)  # Internet  # UDP
+            functions.log("udp socket object success")
             for segment in generator:
                 for span in segment.spans:
+                    functions.log("udp socket object will get data")
                     data = self._get_data(segment, span)
+                    functions.log("udp socket object get data")
                     res = udp_sock.sendto(data, (self.udp_ip, self.udp_port))
+                    functions.log("udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
                     # res = udp_sock.sendto(data, ('fluent-bit', 5140))
                     # res = udp_sock.sendto(data, ('127.0.0.1', 8111))
                     functions.log("sended message: %r, result is: %r", data, res)
